**************************************************************
                *Table 1: Social Networks and Parental Behavior in the 
					*Intergenerational Transmission of Religion *     
                          * Eleonora Patacchini Yves Zenou                             
                            
**************************************************************
**                                                            
**  YEAR:    2015                  
**                                                            
**                                                            
**  Input Data Sets: dbn.dta	 
**  Output tab1.xls tab1f.xls (first step)                                    
**                                       
**                                    
**                                                            
**  Description:  Table 1 paper: Social Networks and Parental Behavior in the 
					*Intergenerational Transmission of Religion * 
** 					        * Eleonora Patacchini Yves Zenou                             

**                                      	
**  Date first written: August 2, 2011
**  Date this vesrion:  December 30, 2015
***************************************************************


clear all

cd ""
use ""



*** coding ethnicity dummies
replace other_races=1 if native==1



********** coding instrument

by  scid female student_grade catholic protestant other_christian jewish muslim other_religion atheist white black asian  native other_races  , sort: egen iv1p=mean(religion_practice_1)

********** coding controls


by scid catholic protestant other_christian jewish muslim other_religion black asian  native  other_races atheist white black asian  native other_races, sort: egen iv1p_av_grade_gender=mean(religion_practice_1)



replace iv1p=. if female==. |student_grade==. |catholic==. |white==.

replace iv1p_av_grade_gender=. if female==. |student_grade==. |catholic==.|white==.


g inter_iv1p=iv1p_av_grade_gender*student_grade



*******drop non religious parents


drop if religion_parent_fr==7


xtset scid

**********************************Whole Sample regressions**********************************************************************



gen std_y=rel_att_par_1

gen std_z=p_religion_practice1

gen std_w=iv1p



local var1 d_grade1 d_grade2 d_grade3 d_grade4 black asian  other_races  student_grade pr_edu_max female math_score_A math_score_B math_score_C math_score_missing   resident_building_quality catholic protestant other_christian jewish muslim other_religion


gen std_iv1pd_av_grade_gender = iv1p_av_grade_gender


gen std_household_size=household_size

gen std_two_parent=two_parent


gen std_inter_iv1pd=inter_iv1p

xtreg   iv1p   `var1' ,fe

**************************************************************************************************

xtreg   p_religion_practice1 iv1p iv1p_av_grade_gender  `var1'  ,fe
outreg2 using tab1f, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel replace ctitle("all")

predict phat2

local var1 d_grade1 d_grade2 d_grade3 d_grade4 black asian  other_races  student_grade pr_edu_max female math_score_A math_score_B math_score_C math_score_missing   resident_building_quality catholic protestant other_christian jewish muslim other_religion
xtivreg2 std_y (  std_z=std_w)  `var1' iv1p_av_grade_gender , fe first


bysort net_id: gen counter=_n if e(sample)==1
sum counter if e(sample)==1

***beta coefficients

sum std_y  if e(sample)==1
g sdy=r(sd)
sum phat2 if e(sample)==1
g sdiv=r(sd)
replace sdiv=sdiv/sdy
 
mat b = e(b)
local bw = b[1,1]
g beta=`bw'*sdiv
outreg2 using tab1, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel replace addstat(F1-test,e(widstat) , "sdiv",beta ) ctitle("all")

sum rel_att_par_1 p_religion_impor_d1 p_religion_impor  p_religion_practice_d1  p_religion_practice1 iv1p female student_grade black asian  other_races    math_score_A math_score_B math_score_C math_score_missing /*
*/ catholic protestant other_christian jewish asian_religion muslim other_religion household_size two_parent  pr_edu_max resident_building_quality/* 
 */ iv1p_av_grade_gender  if e(sample)==1
 
 sum rel_att_par_1 p_religion_impor_d1 p_religion_impor  p_religion_practice_d1  p_religion_practice1 iv1p female student_grade black asian  other_races    math_score_A math_score_B math_score_C math_score_missing /*
*/ catholic protestant other_christian jewish asian_religion muslim other_religion household_size two_parent  pr_edu_max resident_building_quality/* 
 */ iv1p_av_grade_gender
 
**************************************************************************************************

xtreg   p_religion_practice1 iv1p   iv1p_av_grade_gender  `var1' std_household_size std_two_parent ,fe
outreg2 using tab1f, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append  ctitle("all")

predict phat3


xtivreg2  std_y (  std_z=std_w)  `var1' iv1p_av_grade_gender std_household_size std_two_parent , fe first

***beta coefficients

 sum std_y  if e(sample)==1
 g sdy2=r(sd)
 sum phat3 if e(sample)==1
 g sdiv2=r(sd)
 replace sdiv2=sdiv2/sdy2
 mat b = e(b)
local bw = b[1,1]
g beta2=`bw'*sdiv2
outreg2 using tab1, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append addstat(F1-test, e(widstat) , "sdiv",beta2 ) ctitle("all")



xtreg   p_religion_practice1 iv1p iv1p_av_grade_gender  std_inter_iv1pd `var1' std_household_size std_two_parent ,fe
outreg2 using tab1f, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append  ctitle("all")

predict phat4

xtivreg2  std_y (  std_z=std_w) iv1p_av_grade_gender std_inter_iv1pd `var1' std_household_size std_two_parent , fe first
   
   
   ***beta coefficients

   
   
 sum std_y  if e(sample)==1
 g sdy3=r(sd)
 sum phat4 if e(sample)==1
 g sdiv3=r(sd)
 replace sdiv3=sdiv3/sdy3
   mat b = e(b)
local bw = b[1,1]
g beta3=`bw'*sdiv3
outreg2 using tab1, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append addstat(F1-test,e(widstat) ,  "sdiv",beta3  ) ctitle("all")






**********************************Only Christian sample regressions**********************************************************************


keep if (catholic==1 | protestant==1 | other_christian==1 |other_religion==1) 


xtreg   p_religion_practice1 iv1p  iv1p_av_grade_gender   `var1' ,fe
outreg2 using tab1f, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append  ctitle("chri")

predict phat5

xtivreg2 std_y (  std_z=std_w) iv1p_av_grade_gender `var1' , fe first
    sum std_y  if e(sample)==1
 g sdy4=r(sd)
 sum phat5 if e(sample)==1
 g sdiv4=r(sd)
 replace sdiv4=sdiv4/sdy4
   mat b = e(b)
local bw = b[1,1]
g beta4=`bw'*sdiv4
outreg2 using tab1, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append addstat(F1-test, e(widstat),"sdiv",beta4 ) ctitle("chri")

xtreg   p_religion_practice1 iv1p  iv1p_av_grade_gender  `var1' std_household_size std_two_parent ,fe
outreg2 using tab1f, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append  ctitle("chri")

predict phat6

xtivreg2  std_y (  std_z=std_w) iv1p_av_grade_gender `var1' std_household_size std_two_parent , fe first
  sum std_y  if e(sample)==1
 g sdy5=r(sd)
 sum phat6 if e(sample)==1
 g sdiv5=r(sd)

replace sdiv5=sdiv5/sdy5
mat b = e(b)
local bw = b[1,1]
g beta5=`bw'*sdiv5
outreg2 using tab1, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append addstat(F1-test, e(widstat) , "sdiv",beta5 ) ctitle("chri")

xtreg   p_religion_practice1 iv1p iv1p_av_grade_gender  std_inter_iv1pd `var1' std_household_size std_two_parent ,fe
outreg2 using tab1f, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append  ctitle("chri")

predict phat7

xtivreg2  std_y (  std_z=std_w)iv1p_av_grade_gender  std_inter_iv1pd `var1' std_household_size std_two_parent , fe first



  sum std_y  if e(sample)==1
 g sdy6=r(sd)
 sum phat7 if e(sample)==1
 g sdiv6=r(sd)
 replace sdiv6=sdiv6/sdy6
   mat b = e(b)
local bw = b[1,1]
g beta6=`bw'*sdiv6
outreg2 using tab1, bdec(2) nor2 sdec(2) se asterisk(coef)  nolabel excel append addstat(F1-test, e(widstat) ,  "sdiv",beta6 ) ctitle("chri")


************************************************************************************************************************


